# RMT-Audio

- 원격 블루투스 오디오
- remote bluetooth audio


### Dev
```bash
$ git clone ...
$ pdm venv create
$ source .venv/bin/activate
$ pdm install
$ pytest
```



# use
```bash
$ pip install RMT-Audio OR pdm add Remote
$ python
>>> from RMT.Audio.remote import remote as rm
>>> rm() 
```
